@@ -32,6 +32,7 @@ bool MergeArchive(Archive &Arc,ComprDataIO *DataIO,bool ShowFileName,wchar Comma
   if (DataIO!=NULL)
     DataIO->ProcessedArcSize+=Arc.FileLength();
 
+
   Arc.Close();
 
   wchar NextName[NM];
@@ -83,7 +84,7 @@ bool MergeArchive(Archive &Arc,ComprDataIO *DataIO,bool ShowFileName,wchar Comma
       }
 #else // !RARDLL
 
-#if !defined(SFX_MODULE) && !defined(_WIN_CE)
+#ifndef SFX_MODULE
       if (!RecoveryDone)
       {
         RecVolumesRestore(Cmd,Arc.FileName,true);
@@ -112,7 +113,7 @@ bool MergeArchive(Archive &Arc,ComprDataIO *DataIO,bool ShowFileName,wchar Comma
   
   if (FailedOpen)
   {
-#if !defined(SILENT) && !defined(_WIN_CE)
+#ifndef SILENT
       Log(Arc.FileName,St(MAbsNextVol),NextName);
 #endif
     Arc.Open(Arc.FileName,0);
